Index: trunk/src/org/openstreetmap/josm/data/validation/tests/RelationChecker.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/validation/tests/RelationChecker.java	(revision 14989)
+++ trunk/src/org/openstreetmap/josm/data/validation/tests/RelationChecker.java	(revision 14990)
@@ -40,15 +40,15 @@
 
     // CHECKSTYLE.OFF: SingleSpaceSeparator
-    /** Role {0} unknown in templates {1} */
+    /** Role ''{0}'' is not in templates ''{1}'' */
     public static final int ROLE_UNKNOWN     = 1701;
-    /** Empty role type found when expecting one of {0} */
+    /** Empty role found when expecting one of ''{0}'' */
     public static final int ROLE_EMPTY       = 1702;
-    /** Role member does not match expression {0} in template {1} */
-    public static final int WRONG_TYPE       = 1703;
-    /** Number of {0} roles too high ({1}) */
+    /** Role of relation member does not match template expression ''{0}'' in preset {1} */
+    public static final int WRONG_ROLE       = 1708;
+    /** Number of ''{0}'' roles too high ({1}) */
     public static final int HIGH_COUNT       = 1704;
-    /** Number of {0} roles too low ({1}) */
+    /** Number of ''{0}'' roles too low ({1}) */
     public static final int LOW_COUNT        = 1705;
-    /** Role {0} missing */
+    /** Role ''{0}'' missing */
     public static final int ROLE_MISSING     = 1706;
     /** Relation type is unknown */
@@ -56,4 +56,6 @@
     /** Relation is empty */
     public static final int RELATION_EMPTY   = 1708;
+    /** Type ''{0}'' of relation member with role ''{1}'' does not match accepted types ''{2}'' in preset {3} */
+    public static final int WRONG_TYPE       = 1709;
     // CHECKSTYLE.ON: SingleSpaceSeparator
 
@@ -211,5 +213,5 @@
         String role = member.getRole();
         String name = null;
         // Set of all accepted types in template
         Collection<TaggingPresetType> types = EnumSet.noneOf(TaggingPresetType.class);
         TestError possibleMatchError = null;
@@ -242,9 +244,9 @@
                             // possible match error
                             // we still need to iterate further, as we might have
                             // different present, for which memberExpression will match
                             // but stash the error in case no better reason will be found later
-                            possibleMatchError = TestError.builder(this, Severity.WARNING, WRONG_TYPE)
+                            possibleMatchError = TestError.builder(this, Severity.WARNING, WRONG_ROLE)
                                     .message(ROLE_VERIF_PROBLEM_MSG,
-                                            marktr("Role of relation member does not match expression ''{0}'' in template {1}"),
+                                            marktr("Role of relation member does not match template expression ''{0}'' in preset {1}"),
                                             r.memberExpression, name)
                                     .primitives(member.getMember().isUsable() ? member.getMember() : n)
@@ -280,5 +282,5 @@
                 errors.add(TestError.builder(this, Severity.WARNING, WRONG_TYPE)
                         .message(ROLE_VERIF_PROBLEM_MSG,
-                            marktr("Type ''{0}'' of relation member with role ''{1}'' does not match accepted types ''{2}'' in template {3}"),
+                            marktr("Type ''{0}'' of relation member with role ''{1}'' does not match accepted types ''{2}'' in preset {3}"),
                             member.getType(), member.getRole(), typesStr, name)
                         .primitives(member.getMember().isUsable() ? member.getMember() : n)
@@ -293,5 +295,5 @@
      * @param n relation to validate
      * @param allroles contains presets for specified relation
-     * @param map contains statistics of occurrences of specified role types in relation
+     * @param map contains statistics of occurrences of specified role in relation
      */
     private void checkRoles(Relation n, Map<Role, String> allroles, Map<String, RoleInfo> map) {
@@ -333,5 +335,5 @@
                 } else {
                     errors.add(TestError.builder(this, Severity.WARNING, ROLE_EMPTY)
-                            .message(ROLE_VERIF_PROBLEM_MSG, marktr("Empty role type found when expecting one of ''{0}''"), templates)
+                            .message(ROLE_VERIF_PROBLEM_MSG, marktr("Empty role found when expecting one of ''{0}''"), templates)
                             .primitives(n)
                             .build());
@@ -211,5 +213,5 @@
         String role = member.getRole();
         String name = null;
-        // Set of all accepted types in template
+        // Set of all accepted types in preset
         Collection<TaggingPresetType> types = EnumSet.noneOf(TaggingPresetType.class);
         TestError possibleMatchError = null;
@@ -242,9 +244,9 @@
                             // possible match error
                             // we still need to iterate further, as we might have
-                            // different present, for which memberExpression will match
+                            // different preset, for which memberExpression will match
                             // but stash the error in case no better reason will be found later
